import React from 'react';
import ColorPicker from '../../shared/ColorPicker';

type Props = {
  layer: any;
  updatedLayer: any;
  graphInfo: any;
  deleteLayer: any;
};

export default function NodeLinkOptions({ layer, updatedLayer, graphInfo, deleteLayer }: Props) {
  return (
    <div>
      <div className="divider m-0"></div>

      <div>
        <h5>Edges</h5>
        <div className="form-control">
          <label className="label cursor-pointer">
            <span className="label-text">Edges on hover</span>
            <input
              className="checkbox"
              type="checkbox"
              checked={layer.config.edgesOnHover}
              onChange={(e) =>
                updatedLayer(layer.id, {
                  config: {
                    ...layer.config,
                    edgesOnHover: e.target.checked,
                  },
                })
              }
            />
          </label>
        </div>
      </div>

      <div className="divider m-0"></div>

      <div>
        <h5>Nodes</h5>
        <div className="form-control">
          <label className="label cursor-pointer">
            <span className="label-text">Show node labels</span>
            <input
              className="checkbox"
              type="checkbox"
              checked={layer.config.showLabels}
              onChange={(e) =>
                updatedLayer(layer.id, {
                  config: {
                    ...layer.config,
                    showLabels: e.target.checked,
                  },
                })
              }
            />
          </label>
        </div>

        <div className="form-control">
          <label className="label cursor-pointer">
            <span className="label-text">Dynamic node size</span>
            <input
              className="checkbox"
              type="checkbox"
              checked={layer.config.nodeSizeDynamic}
              onChange={(e) =>
                updatedLayer(layer.id, {
                  config: {
                    ...layer.config,
                    nodeSizeDynamic: e.target.checked,
                  },
                })
              }
            />
          </label>
        </div>

        {!layer.config.nodeSizeDynamic && (
          <div>
            <p>Node size</p>
            <input
              value={layer.config.nodeSize}
              type="number"
              min={1}
              onChange={(e) =>
                updatedLayer(layer.id, {
                  config: {
                    ...layer.config,
                    nodeSize: parseInt(e.target.value),
                  },
                })
              }
            />
          </div>
        )}

        <div className="form-control">
          <label className="label cursor-pointer">
            <span className="label-text">Dynamic node shape/color</span>
            <input
              className="checkbox"
              type="checkbox"
              checked={layer.config.nodeShapeDynamic}
              onChange={(e) =>
                updatedLayer(layer.id, {
                  config: {
                    ...layer.config,
                    nodeShapeDynamic: e.target.checked,
                  },
                })
              }
            />
          </label>
        </div>

        {layer.config.nodeShapeDynamic && (
          <select
            className="select select-bordered w-full max-w-xs"
            value={layer.config.shapeAccessor}
            onChange={(e) =>
              updatedLayer(layer.id, {
                config: {
                  ...layer.config,
                  shapeAccessor: e.target.value,
                },
              })
            }
          >
            <option disabled selected>
              Shape Attribute
            </option>
            {Object.keys(graphInfo.nodeAttributes).map((type) => (
              <option key={type} value={type}>
                {type}
              </option>
            ))}
          </select>
        )}

        {layer.config.nodeShapeDynamic && layer.config.shapeAccessor && (
          <div>
            {[...graphInfo.nodeAttributes[layer.config.shapeAccessor]?.values].map((val, index) => (
              <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
                <p key={index}>{val}</p>
                <select
                  value={layer.config.iconMapping[val] || ''}
                  onChange={(e) =>
                    updatedLayer(layer.id, {
                      config: {
                        ...layer.config,
                        iconMapping: {
                          ...layer.config.iconMapping,
                          [val]: e.target.value,
                        },
                      },
                    })
                  }
                >
                  <option value="diamond">Diamond</option>
                  <option value="location">Location</option>
                  <option value="circle">Circle</option>
                  <option value="square">Square</option>
                  <option value="triangle">Triangle</option>
                  <option value="star">Star</option>
                </select>
                <ColorPicker
                  value={layer.config.colorMapping[val] || ''}
                  updateValue={(newValue: any) =>
                    updatedLayer(layer.id, {
                      config: {
                        ...layer.config,
                        colorMapping: {
                          ...layer.config.colorMapping,
                          [val]: newValue,
                        },
                      },
                    })
                  }
                />
              </div>
            ))}
          </div>
        )}
      </div>

      <div className="divider m-0"></div>

      <div>
        <button
          className="btn btn-primary w-full"
          onClick={() =>
            updatedLayer(layer.id, {
              visible: !layer.visible,
            })
          }
        >
          {layer.visible ? 'Hide layer' : 'Show layer'}
        </button>

        <button className="btn btn-outline btn-primary w-full mt-1" onClick={() => deleteLayer(layer.id)}>
          Delete Layer
        </button>
      </div>
    </div>
  );
}
