import React from 'react';
import { Meta } from '@storybook/react';
import { VisualizationPanel } from '../../visualizationPanel';
import { Provider } from 'react-redux';
import { configureStore } from '@reduxjs/toolkit';
import {
  assignNewGraphQueryResult,
  graphQueryResultSlice,
  querybuilderSlice,
  schemaSlice,
  visualizationSlice,
} from '../../../data-access/store';
import { mockMobilityQueryResult, bigMockQueryResults } from '../../../mock-data';
import { setActiveVisualization } from '@graphpolaris/shared/lib/data-access/store/visualizationSlice';

const Component: Meta<typeof VisualizationPanel> = {
  title: 'Visualizations/MapVis',
  component: VisualizationPanel,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

export const DutchVehicleTheft = {
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(assignNewGraphQueryResult({ queryID: '1', result: { type: 'nodelink', payload: mockMobilityQueryResult } }));
    dispatch(setActiveVisualization('MapVis'));
  },
};

export const AmericanFlights = {
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(assignNewGraphQueryResult({ queryID: '1', result: { type: 'nodelink', payload: bigMockQueryResults } }));
    dispatch(setActiveVisualization('MapVis'));
  },
};

export default Component;
